@@ -32,7 +32,7 @@ class TestWebHandler(TestCase):
 
     def test_deployment_mode_set_to_development(self):
         conf = {
-            'server': {
+            'leon': {
                 'deployment_mode': 'development'
             }
         }
